/*   gloSerialOLED Library -  gloSetCursor_UART

This sketch shows how to use the Seetron gloSerialOLED macros to
talk to a GLO-216 or GLO-416 serial OLED using an Arduino 
hardware serial port (UART). This program is meant for boards
like the Mega that have more than one hardware UART. 
Sharing the bootloader port is _not_ recommended. 

====================================================================
MACRO(S) DEMONSTRATED: 

gloSetCursor( col, row )

Sets the next printing position to col, row
where col is the horizontal position on the screen 
(0 - 15), and row is the screen line: 0 or 1 for a 2-line
display, and 0-3 for a 4-line. 

Alternatives: There are two other macros in the library 
that let you express the position differently--as row, col
or as a single position number spanning the whole screen
(i.e., 0 to 31 for the GLO-216 or 0 to 63 for GLO-416).
All do the same thing; use whichever seems easiest. 

gloSetRowCol( row, col )  // Rows, cols reversed
gloSetPosition( charLoc )  // charLoc is 0-31 or 0-63 (2x16 or 4x16)

====================================================================
Connections:
GLO +5 to Arduino +5V
GLO GND to Arduino GND
GLO SER to Arduino pin TX1
GLO SPOL jumper: Cut
____________
History:
1st Release 2 June 2014
(Tested under IDE version 1.5.6-r2 w/ Arduino MEGA 2560, Arduino UNO)

____________
More Info:
seetron.com or email tech@seetron.com
*/

// Include SoftwareSerial 
#include <SoftwareSerial.h>

// Include gloSerialOLED _and_ the 'streaming' template, which lets you combine 
// multiple print()s into a single line. This is required by the serial OLED macros. 
#include <gloSerialOLED.h>
gloStreamingTemplate

// Initialize SoftwareSerial by naming the serial object, and
// specifying the output pin and serial polarity (SPOL).
// If the SPOL jumper on the GLO is intact, use "inverted."
// If SPOL is cut, use "noninverted."

gloSoftSerialSetup( myOLED, 3, noninverted );

// Note that this is _outside_ of the standard Arduino setup
// and loop blocks. This makes the serial object visible/usable
// globally--in both setup() and loop().

// Change to numRows = 4; for GLO416.  
const byte numRows = 2;
const byte numCols = 16;

//===================================================================
void setup() {
// Begin using the serial object created above.
  gloSoftSerialBegin( myOLED ) ;
  
// Allow 1/4 sec for the OLED to start up. 
  delay(250) ; 

// Clear the screen and set to the smallest font.
  myOLED << gloClear << gloFont_1w1h ;

// Use gloSetCursor to move to char 2 of line 0, print "gloSetCursor" 
// then move to character 6 of line 1 and print "Demo"
  myOLED << gloSetCursor( 2,0 ) << "gloSetCursor" << gloSetCursor( 6,1 ) << "Demo" ;
  delay(1000) ;  // Pause before next step. 
  myOLED << gloClear ;  // Clear screen. 
  
// With a little calculation, we can center text on a line:  
// Subtract half of the length of the text from the length of the 
// line and set that as the starting position for printing. 
// Try changing text1 and text2 to see how this works.  
 
  String text1 = "==Seetron==" ;  // String objects w/ demo text. 
  String text2 = "=OLEDs=" ;

  myOLED << gloSetCursor( (numCols- text1.length())/2 ,0 ) << text1 ;
  myOLED << gloSetCursor( (numCols- text2.length())/2 ,1 ) << text2 ;
  
  delay(1000) ;  // Pause before next step. 
}

//===================================================================
/* Just for fun, we'll 'erase' the screen by printing random 
   characters A - z at random locations on the screen. 
   Note that the random() that generates the character must
   be converted to a 'char' type. Otherwise, it'd print random 
   numbers all over the screen. Nothing to do with the OLED or the  
   library, but something to watch for when you're printing data. */ 
void loop() {
  myOLED << gloSetCursor(random(0,numCols),random(0,numRows)) << char( random('A',('z'+1)) );
  delay(50) ;
}
